@@ -8,17 +8,23 @@ plot.diamonds <- ggplot(diamonds, aes(clarity, fill = cut)) + geom_bar() +
 plot_grid(plot.mpg, plot.diamonds, labels = c('A', 'B'))
 
 ## ---- message=FALSE, fig.width=6.8, fig.height=2.55----------------------
-plot_grid(plot.mpg, plot.diamonds, labels = c('A', 'B'), align = 'h')
+plot_grid(plot.mpg, plot.diamonds, labels = "AUTO")
+
+## ---- message=FALSE, fig.width=6.8, fig.height=2.55----------------------
+plot_grid(plot.mpg, plot.diamonds, labels = "auto")
+
+## ---- message=FALSE, fig.width=6.8, fig.height=2.55----------------------
+plot_grid(plot.mpg, plot.diamonds, labels = "AUTO", align = 'h')
 
 ## ---- message=FALSE, fig.width=3.9, fig.height=5.1-----------------------
-plot_grid(plot.mpg, plot.diamonds, labels = c('A', 'B'), ncol = 1, align = 'v')
+plot_grid(plot.mpg, plot.diamonds, labels = "AUTO", ncol = 1, align = 'v')
 
 ## ---- message=FALSE, fig.width=4.25, fig.height=5.1----------------------
 plot.iris <- ggplot(iris, aes(Sepal.Length, Sepal.Width)) + 
   geom_point() + facet_grid(. ~ Species) + stat_smooth(method = "lm") +
   background_grid(major = 'y', minor = "none") + # add thin horizontal lines 
   panel_border() # and a border around each panel
-plot_grid(plot.iris, plot.mpg, labels = c('A', 'B'), ncol = 1, 
+plot_grid(plot.iris, plot.mpg, labels = "AUTO", ncol = 1, 
           align = 'v') # aligning does not work here
 
 ## ---- message=FALSE, fig.width=4.25, fig.height=5.1----------------------
@@ -34,20 +40,20 @@ g.iris$widths[1:3] <- max.widths # assign max. widths to iris gtable
 g.mpg$widths[1:3] <- max.widths # assign max widths to mpg gtable
 
 # plot_grid() can work directly with gtables, so this works
-plot_grid(g.iris, g.mpg, labels = c('A', 'B'), ncol = 1)
+plot_grid(g.iris, g.mpg, labels = "AUTO", ncol = 1)
 
 ## ---- message=FALSE, fig.width=6.8, fig.height=2.55----------------------
-plot_grid(plot.mpg, plot.diamonds, labels = c('A', 'B'), align = 'h', label_size = 12)
+plot_grid(plot.mpg, plot.diamonds, labels = "AUTO", align = 'h', label_size = 12)
 
 ## ---- message=FALSE, fig.width=6.8, fig.height=2.55----------------------
-plot_grid(plot.mpg, plot.diamonds, labels = c('A', 'B'), align = 'h', label_size = 12,
+plot_grid(plot.mpg, plot.diamonds, labels = "AUTO", align = 'h', label_size = 12,
           hjust = -1, vjust = 2.5 )
 
 ## ---- message=FALSE, fig.width=6.8, fig.height=2.55----------------------
-plot_grid(plot.mpg, plot.diamonds, labels = c('A', 'B'), align = 'h', rel_widths = c(1, 1.3))
+plot_grid(plot.mpg, plot.diamonds, labels = "AUTO", align = 'h', rel_widths = c(1, 1.3))
 
 ## ---- message=FALSE, fig.width=6.8, fig.height=2.55----------------------
-plot_grid(plot.mpg, plot.diamonds, labels = c('A', 'B'), align = 'h', rel_widths = c(1, 1.3), scale = 0.95)
+plot_grid(plot.mpg, plot.diamonds, labels = "AUTO", align = 'h', rel_widths = c(1, 1.3), scale = 0.95)
 
 ## ---- message=FALSE, fig.width=7.65, fig.height=5.1----------------------
 bottom_row <- plot_grid(plot.mpg, plot.diamonds, labels = c('B', 'C'), align = 'h', rel_widths = c(1, 1.3))
